@@ -121,7 +121,7 @@ pango_context_finalize (GObject *object)
   context = PANGO_CONTEXT (object);
 
   if (context->font_map)
-    g_object_unref (G_OBJECT(context->font_map));
+    g_object_unref (context->font_map);
 
   pango_font_description_free (context->font_desc);
   
@@ -141,7 +141,7 @@ pango_context_new (void)
 {
   PangoContext *context;
 
-  context = PANGO_CONTEXT (g_type_create_instance (pango_context_get_type ()));
+  context = g_object_new (PANGO_TYPE_CONTEXT, NULL);
   
   return context;
 }
@@ -157,13 +157,15 @@ void
 pango_context_set_font_map (PangoContext *context,
 			    PangoFontMap *font_map)
 {
-  g_return_if_fail (context != NULL);
-  g_return_if_fail (font_map != NULL);
+  g_return_if_fail (PANGO_IS_CONTEXT (context));
+  g_return_if_fail (!font_map || PANGO_IS_FONT_MAP (font_map));
 
   if (context->font_map)
-    g_object_unref (G_OBJECT (context->font_map));
+    g_object_unref (context->font_map);
+
+  if (font_map)
+    g_object_ref (font_map);
 
-  g_object_ref (G_OBJECT (font_map));
   context->font_map = font_map;
 }
 
@@ -214,7 +216,9 @@ pango_context_load_font (PangoContext               *context,
 			 const PangoFontDescription *desc)
 {
   g_return_val_if_fail (context != NULL, NULL);
-
+  g_return_val_if_fail (pango_font_description_get_family (desc) != NULL, NULL);
+  g_return_val_if_fail (pango_font_description_get_size (desc) != 0, NULL);
+  
   return pango_font_map_load_font (context->font_map, context, desc);
 }
 
@@ -235,6 +239,8 @@ pango_context_load_fontset (PangoContext               *context,
 			     PangoLanguage             *language)
 {
   g_return_val_if_fail (context != NULL, NULL);
+  g_return_val_if_fail (pango_font_description_get_family (desc) != NULL, NULL);
+  g_return_val_if_fail (pango_font_description_get_size (desc) != 0, NULL);
 
   return pango_font_map_load_fontset (context->font_map, context, desc, language);
 }
@@ -633,8 +639,6 @@ add_engines (PangoContext      *context,
 	      static guint engine_type_id = 0;
 	      static guint render_type_id = 0;
 	      
-	      language = next_language;
-
 	      if (engine_type_id == 0)
 		{
 		  engine_type_id = g_quark_from_static_string (PANGO_ENGINE_TYPE_LANG);
@@ -645,11 +649,14 @@ add_engines (PangoContext      *context,
 					 engine_type_id, render_type_id);
 	    }
 
-	  if (i == 0 || !pango_font_description_equal (current_desc, next_desc))
+	  if (i == 0 ||
+	      language != next_language ||
+	      !pango_font_description_equal (current_desc, next_desc))
 	    {
 	      pango_font_description_free (current_desc);
 	      current_desc = next_desc;
-
+	      language = next_language;
+	      
 	      if (current_fonts)
 		g_object_unref (current_fonts);
 	      
